@@ -23,22 +23,9 @@ This module contains a Google AutoML hook.
 
     PredictResponse
 """
-import sys
 from typing import Dict, Optional, Sequence, Tuple, Union
 
-from google.cloud.automl_v1beta1.services.auto_ml.pagers import (
-    ListColumnSpecsPager,
-    ListDatasetsPager,
-    ListTableSpecsPager,
-)
-
-from airflow.providers.google.common.consts import CLIENT_INFO
-
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    from cached_property import cached_property
-
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.operation import Operation
 from google.api_core.retry import Retry
 from google.cloud.automl_v1beta1 import (
@@ -53,8 +40,15 @@ from google.cloud.automl_v1beta1 import (
     PredictionServiceClient,
     PredictResponse,
 )
+from google.cloud.automl_v1beta1.services.auto_ml.pagers import (
+    ListColumnSpecsPager,
+    ListDatasetsPager,
+    ListTableSpecsPager,
+)
 from google.protobuf.field_mask_pb2 import FieldMask
 
+from airflow.compat.functools import cached_property
+from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
 
 
@@ -113,7 +107,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         project_id: str = PROVIDE_PROJECT_ID,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
     ) -> Operation:
         """
         Creates a model_id. Returns a Model in the `response` field when it
@@ -152,7 +146,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         location: str,
         project_id: str = PROVIDE_PROJECT_ID,
         params: Optional[Dict[str, str]] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Operation:
@@ -204,7 +198,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         location: str,
         project_id: str = PROVIDE_PROJECT_ID,
         params: Optional[Dict[str, str]] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> PredictResponse:
@@ -244,7 +238,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         dataset: Union[dict, Dataset],
         location: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Dataset:
@@ -281,7 +275,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         location: str,
         input_config: Union[dict, InputConfig],
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Operation:
@@ -322,7 +316,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         field_mask: Optional[Union[dict, FieldMask]] = None,
         filter_: Optional[str] = None,
         page_size: Optional[int] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> ListColumnSpecsPager:
@@ -371,7 +365,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         model_id: str,
         location: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Model:
@@ -406,10 +400,10 @@ class CloudAutoMLHook(GoogleBaseHook):
         model_id: str,
         location: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> Model:
+    ) -> Operation:
         """
         Deletes a AutoML model.
 
@@ -439,7 +433,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         self,
         dataset: Union[dict, Dataset],
         update_mask: Optional[Union[dict, FieldMask]] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Dataset:
@@ -474,14 +468,14 @@ class CloudAutoMLHook(GoogleBaseHook):
         location: str,
         project_id: str = PROVIDE_PROJECT_ID,
         image_detection_metadata: Optional[Union[ImageObjectDetectionModelDeploymentMetadata, dict]] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Operation:
         """
         Deploys a model. If a model is already deployed, deploying it with the same parameters
         has no effect. Deploying with different parameters (as e.g. changing node_number) will
-        reset the deployment state without pausing the model_id’s availability.
+        reset the deployment state without pausing the model_id's availability.
 
         Only applicable for Text Classification, Image Object Detection and Tables; all other
         domains manage deployment automatically.
@@ -521,7 +515,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         project_id: Optional[str] = None,
         filter_: Optional[str] = None,
         page_size: Optional[int] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> ListTableSpecsPager:
@@ -564,7 +558,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         self,
         location: str,
         project_id: str,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> ListDatasetsPager:
@@ -601,7 +595,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         dataset_id: str,
         location: str,
         project_id: str,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Operation:
