@@ -18,12 +18,14 @@
 from typing import TYPE_CHECKING, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core.exceptions import AlreadyExists, NotFound
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
-from google.cloud.datacatalog_v1beta1 import DataCatalogClient, SearchCatalogResult
-from google.cloud.datacatalog_v1beta1.types import (
+from google.cloud.datacatalog import (
+    DataCatalogClient,
     Entry,
     EntryGroup,
     SearchCatalogRequest,
+    SearchCatalogResult,
     Tag,
     TagTemplate,
     TagTemplateField,
@@ -32,6 +34,11 @@ from google.protobuf.field_mask_pb2 import FieldMask
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.datacatalog import CloudDataCatalogHook
+from airflow.providers.google.cloud.links.datacatalog import (
+    DataCatalogEntryGroupLink,
+    DataCatalogEntryLink,
+    DataCatalogTagTemplateLink,
+)
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -86,6 +93,7 @@ class CloudDataCatalogCreateEntryOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogEntryLink(),)
 
     def __init__(
         self,
@@ -95,7 +103,7 @@ class CloudDataCatalogCreateEntryOperator(BaseOperator):
         entry_id: str,
         entry: Union[Dict, Entry],
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -142,7 +150,15 @@ class CloudDataCatalogCreateEntryOperator(BaseOperator):
             )
         _, _, entry_id = result.name.rpartition("/")
         self.log.info("Current entry_id ID: %s", entry_id)
-        context["task_instance"].xcom_push(key="entry_id", value=entry_id)
+        self.xcom_push(context, key="entry_id", value=entry_id)
+        DataCatalogEntryLink.persist(
+            context=context,
+            task_instance=self,
+            entry_id=self.entry_id,
+            entry_group_id=self.entry_group,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
         return Entry.to_dict(result)
 
 
@@ -194,6 +210,7 @@ class CloudDataCatalogCreateEntryGroupOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogEntryGroupLink(),)
 
     def __init__(
         self,
@@ -202,7 +219,7 @@ class CloudDataCatalogCreateEntryGroupOperator(BaseOperator):
         entry_group_id: str,
         entry_group: Union[Dict, EntryGroup],
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -247,7 +264,14 @@ class CloudDataCatalogCreateEntryGroupOperator(BaseOperator):
 
         _, _, entry_group_id = result.name.rpartition("/")
         self.log.info("Current entry group ID: %s", entry_group_id)
-        context["task_instance"].xcom_push(key="entry_group_id", value=entry_group_id)
+        self.xcom_push(context, key="entry_group_id", value=entry_group_id)
+        DataCatalogEntryGroupLink.persist(
+            context=context,
+            task_instance=self,
+            entry_group_id=self.entry_group_id,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
         return EntryGroup.to_dict(result)
 
 
@@ -300,6 +324,7 @@ class CloudDataCatalogCreateTagOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogEntryLink(),)
 
     def __init__(
         self,
@@ -310,7 +335,7 @@ class CloudDataCatalogCreateTagOperator(BaseOperator):
         tag: Union[Dict, Tag],
         template_id: Optional[str] = None,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -374,7 +399,15 @@ class CloudDataCatalogCreateTagOperator(BaseOperator):
 
         _, _, tag_id = tag.name.rpartition("/")
         self.log.info("Current Tag ID: %s", tag_id)
-        context["task_instance"].xcom_push(key="tag_id", value=tag_id)
+        self.xcom_push(context, key="tag_id", value=tag_id)
+        DataCatalogEntryLink.persist(
+            context=context,
+            task_instance=self,
+            entry_id=self.entry,
+            entry_group_id=self.entry_group,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
         return Tag.to_dict(tag)
 
 
@@ -424,6 +457,7 @@ class CloudDataCatalogCreateTagTemplateOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogTagTemplateLink(),)
 
     def __init__(
         self,
@@ -432,7 +466,7 @@ class CloudDataCatalogCreateTagTemplateOperator(BaseOperator):
         tag_template_id: str,
         tag_template: Union[Dict, TagTemplate],
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -476,7 +510,14 @@ class CloudDataCatalogCreateTagTemplateOperator(BaseOperator):
             )
         _, _, tag_template = result.name.rpartition("/")
         self.log.info("Current Tag ID: %s", tag_template)
-        context["task_instance"].xcom_push(key="tag_template_id", value=tag_template)
+        self.xcom_push(context, key="tag_template_id", value=tag_template)
+        DataCatalogTagTemplateLink.persist(
+            context=context,
+            task_instance=self,
+            tag_template_id=self.tag_template_id,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
         return TagTemplate.to_dict(result)
 
 
@@ -531,6 +572,7 @@ class CloudDataCatalogCreateTagTemplateFieldOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogTagTemplateLink(),)
 
     def __init__(
         self,
@@ -540,7 +582,7 @@ class CloudDataCatalogCreateTagTemplateFieldOperator(BaseOperator):
         tag_template_field_id: str,
         tag_template_field: Union[Dict, TagTemplateField],
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -587,7 +629,14 @@ class CloudDataCatalogCreateTagTemplateFieldOperator(BaseOperator):
             result = tag_template.fields[self.tag_template_field_id]
 
         self.log.info("Current Tag ID: %s", self.tag_template_field_id)
-        context["task_instance"].xcom_push(key="tag_template_field_id", value=self.tag_template_field_id)
+        self.xcom_push(context, key="tag_template_field_id", value=self.tag_template_field_id)
+        DataCatalogTagTemplateLink.persist(
+            context=context,
+            task_instance=self,
+            tag_template_id=self.tag_template,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
         return TagTemplateField.to_dict(result)
 
 
@@ -640,7 +689,7 @@ class CloudDataCatalogDeleteEntryOperator(BaseOperator):
         entry_group: str,
         entry: str,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -724,7 +773,7 @@ class CloudDataCatalogDeleteEntryGroupOperator(BaseOperator):
         location: str,
         entry_group: str,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -810,7 +859,7 @@ class CloudDataCatalogDeleteTagOperator(BaseOperator):
         entry: str,
         tag: str,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -899,7 +948,7 @@ class CloudDataCatalogDeleteTagTemplateOperator(BaseOperator):
         tag_template: str,
         force: bool,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -987,7 +1036,7 @@ class CloudDataCatalogDeleteTagTemplateFieldOperator(BaseOperator):
         field: str,
         force: bool,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -1066,6 +1115,7 @@ class CloudDataCatalogGetEntryOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogEntryLink(),)
 
     def __init__(
         self,
@@ -1074,7 +1124,7 @@ class CloudDataCatalogGetEntryOperator(BaseOperator):
         entry_group: str,
         entry: str,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -1105,6 +1155,14 @@ class CloudDataCatalogGetEntryOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        DataCatalogEntryLink.persist(
+            context=context,
+            task_instance=self,
+            entry_id=self.entry,
+            entry_group_id=self.entry_group,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
         return Entry.to_dict(result)
 
 
@@ -1152,6 +1210,7 @@ class CloudDataCatalogGetEntryGroupOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogEntryGroupLink(),)
 
     def __init__(
         self,
@@ -1160,7 +1219,7 @@ class CloudDataCatalogGetEntryGroupOperator(BaseOperator):
         entry_group: str,
         read_mask: FieldMask,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -1191,6 +1250,13 @@ class CloudDataCatalogGetEntryGroupOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        DataCatalogEntryGroupLink.persist(
+            context=context,
+            task_instance=self,
+            entry_group_id=self.entry_group,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
         return EntryGroup.to_dict(result)
 
 
@@ -1233,6 +1299,7 @@ class CloudDataCatalogGetTagTemplateOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogTagTemplateLink(),)
 
     def __init__(
         self,
@@ -1240,7 +1307,7 @@ class CloudDataCatalogGetTagTemplateOperator(BaseOperator):
         location: str,
         tag_template: str,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -1269,6 +1336,13 @@ class CloudDataCatalogGetTagTemplateOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        DataCatalogTagTemplateLink.persist(
+            context=context,
+            task_instance=self,
+            tag_template_id=self.tag_template,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
         return TagTemplate.to_dict(result)
 
 
@@ -1318,6 +1392,7 @@ class CloudDataCatalogListTagsOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogEntryLink(),)
 
     def __init__(
         self,
@@ -1327,7 +1402,7 @@ class CloudDataCatalogListTagsOperator(BaseOperator):
         entry: str,
         page_size: int = 100,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -1360,6 +1435,14 @@ class CloudDataCatalogListTagsOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        DataCatalogEntryLink.persist(
+            context=context,
+            task_instance=self,
+            entry_id=self.entry,
+            entry_group_id=self.entry_group,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
         return [Tag.to_dict(item) for item in result]
 
 
@@ -1405,6 +1488,7 @@ class CloudDataCatalogLookupEntryOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogEntryLink(),)
 
     def __init__(
         self,
@@ -1412,7 +1496,7 @@ class CloudDataCatalogLookupEntryOperator(BaseOperator):
         linked_resource: Optional[str] = None,
         sql_resource: Optional[str] = None,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -1440,6 +1524,16 @@ class CloudDataCatalogLookupEntryOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+
+        project_id, location_id, entry_group_id, entry_id = result.name.split('/')[1::2]
+        DataCatalogEntryLink.persist(
+            context=context,
+            task_instance=self,
+            entry_id=entry_id,
+            entry_group_id=entry_group_id,
+            location_id=location_id,
+            project_id=project_id,
+        )
         return Entry.to_dict(result)
 
 
@@ -1488,6 +1582,7 @@ class CloudDataCatalogRenameTagTemplateFieldOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogTagTemplateLink(),)
 
     def __init__(
         self,
@@ -1497,7 +1592,7 @@ class CloudDataCatalogRenameTagTemplateFieldOperator(BaseOperator):
         field: str,
         new_tag_template_field_id: str,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -1530,6 +1625,13 @@ class CloudDataCatalogRenameTagTemplateFieldOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        DataCatalogTagTemplateLink.persist(
+            context=context,
+            task_instance=self,
+            tag_template_id=self.tag_template,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
 
 
 class CloudDataCatalogSearchCatalogOperator(BaseOperator):
@@ -1608,7 +1710,7 @@ class CloudDataCatalogSearchCatalogOperator(BaseOperator):
         query: str,
         page_size: int = 100,
         order_by: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -1694,6 +1796,7 @@ class CloudDataCatalogUpdateEntryOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogEntryLink(),)
 
     def __init__(
         self,
@@ -1704,7 +1807,7 @@ class CloudDataCatalogUpdateEntryOperator(BaseOperator):
         entry_group: Optional[str] = None,
         entry_id: Optional[str] = None,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -1728,7 +1831,7 @@ class CloudDataCatalogUpdateEntryOperator(BaseOperator):
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
-        hook.update_entry(
+        result = hook.update_entry(
             entry=self.entry,
             update_mask=self.update_mask,
             location=self.location,
@@ -1740,6 +1843,16 @@ class CloudDataCatalogUpdateEntryOperator(BaseOperator):
             metadata=self.metadata,
         )
 
+        location_id, entry_group_id, entry_id = result.name.split("/")[3::2]
+        DataCatalogEntryLink.persist(
+            context=context,
+            task_instance=self,
+            entry_id=self.entry_id or entry_id,
+            entry_group_id=self.entry_group or entry_group_id,
+            location_id=self.location or location_id,
+            project_id=self.project_id or hook.project_id,
+        )
+
 
 class CloudDataCatalogUpdateTagOperator(BaseOperator):
     """
@@ -1794,6 +1907,7 @@ class CloudDataCatalogUpdateTagOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogEntryLink(),)
 
     def __init__(
         self,
@@ -1805,7 +1919,7 @@ class CloudDataCatalogUpdateTagOperator(BaseOperator):
         entry: Optional[str] = None,
         tag_id: Optional[str] = None,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -1830,7 +1944,7 @@ class CloudDataCatalogUpdateTagOperator(BaseOperator):
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
-        hook.update_tag(
+        result = hook.update_tag(
             tag=self.tag,
             update_mask=self.update_mask,
             location=self.location,
@@ -1843,6 +1957,16 @@ class CloudDataCatalogUpdateTagOperator(BaseOperator):
             metadata=self.metadata,
         )
 
+        location_id, entry_group_id, entry_id = result.name.split("/")[3:8:2]
+        DataCatalogEntryLink.persist(
+            context=context,
+            task_instance=self,
+            entry_id=self.entry or entry_id,
+            entry_group_id=self.entry_group or entry_group_id,
+            location_id=self.location or location_id,
+            project_id=self.project_id or hook.project_id,
+        )
+
 
 class CloudDataCatalogUpdateTagTemplateOperator(BaseOperator):
     """
@@ -1899,6 +2023,7 @@ class CloudDataCatalogUpdateTagTemplateOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogTagTemplateLink(),)
 
     def __init__(
         self,
@@ -1908,7 +2033,7 @@ class CloudDataCatalogUpdateTagTemplateOperator(BaseOperator):
         location: Optional[str] = None,
         tag_template_id: Optional[str] = None,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -1931,7 +2056,7 @@ class CloudDataCatalogUpdateTagTemplateOperator(BaseOperator):
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
-        hook.update_tag_template(
+        result = hook.update_tag_template(
             tag_template=self.tag_template,
             update_mask=self.update_mask,
             location=self.location,
@@ -1942,6 +2067,15 @@ class CloudDataCatalogUpdateTagTemplateOperator(BaseOperator):
             metadata=self.metadata,
         )
 
+        location_id, tag_template_id = result.name.split("/")[3::2]
+        DataCatalogTagTemplateLink.persist(
+            context=context,
+            task_instance=self,
+            tag_template_id=self.tag_template_id or tag_template_id,
+            location_id=self.location or location_id,
+            project_id=self.project_id or hook.project_id,
+        )
+
 
 class CloudDataCatalogUpdateTagTemplateFieldOperator(BaseOperator):
     """
@@ -2004,6 +2138,7 @@ class CloudDataCatalogUpdateTagTemplateFieldOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (DataCatalogTagTemplateLink(),)
 
     def __init__(
         self,
@@ -2015,7 +2150,7 @@ class CloudDataCatalogUpdateTagTemplateFieldOperator(BaseOperator):
         tag_template: Optional[str] = None,
         tag_template_field_id: Optional[str] = None,
         project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
+        retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
@@ -2040,7 +2175,7 @@ class CloudDataCatalogUpdateTagTemplateFieldOperator(BaseOperator):
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
-        hook.update_tag_template_field(
+        result = hook.update_tag_template_field(
             tag_template_field=self.tag_template_field,
             update_mask=self.update_mask,
             tag_template_field_name=self.tag_template_field_name,
@@ -2052,3 +2187,12 @@ class CloudDataCatalogUpdateTagTemplateFieldOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+
+        location_id, tag_template_id = result.name.split("/")[3:6:2]
+        DataCatalogTagTemplateLink.persist(
+            context=context,
+            task_instance=self,
+            tag_template_id=self.tag_template or tag_template_id,
+            location_id=self.location or location_id,
+            project_id=self.project_id or hook.project_id,
+        )
