@@ -38,19 +38,13 @@ class GoogleCampaignManagerReportSensor(BaseSensorOperator):
         :ref:`howto/operator:GoogleCampaignManagerReportSensor`
 
     :param profile_id: The DFA user profile ID.
-    :type profile_id: str
     :param report_id: The ID of the report.
-    :type report_id: str
     :param file_id: The ID of the report file.
-    :type file_id: str
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -59,7 +53,6 @@ class GoogleCampaignManagerReportSensor(BaseSensorOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
